==> haskell-fgl-5.8.2.0-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fgl
version:              5.8.2.0
visibility:           public
id:                   fgl-5.8.2.0-9xKCfKf7Jnm7bBKKT2bzyG
key:                  fgl-5.8.2.0-9xKCfKf7Jnm7bBKKT2bzyG
license:              BSD-3-Clause
maintainer:           athas@sigkill.dk
author:               Martin Erwig, Ivan Lazar Miljenovic
synopsis:             Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.

    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.

category:             Data Structures, Graphs
abi:                  302f5d88e0ee812a44d01f52d2dbf471
exposed:              True
exposed-modules:
    Data.Graph.Inductive Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Monad
    Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive.Tree

hidden-modules:       Paths_fgl
import-dirs:          /usr/lib/ghc-9.2.8/site-local/fgl-5.8.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fgl-5.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl
hs-libraries:         HSfgl-5.8.2.0-9xKCfKf7Jnm7bBKKT2bzyG
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html:         /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-5.8.2.0-10-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fgl
version:              5.8.2.0
visibility:           public
id:                   fgl-5.8.2.0-Eb6xdEigYbA8WAuh82pZJA
key:                  fgl-5.8.2.0-Eb6xdEigYbA8WAuh82pZJA
license:              BSD-3-Clause
maintainer:           athas@sigkill.dk
author:               Martin Erwig, Ivan Lazar Miljenovic
synopsis:             Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.

    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.

category:             Data Structures, Graphs
abi:                  f8b18e452bd6f35c6bf77beeb70ead97
exposed:              True
exposed-modules:
    Data.Graph.Inductive Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Monad
    Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive.Tree

hidden-modules:       Paths_fgl
import-dirs:          /usr/lib/ghc-9.2.8/site-local/fgl-5.8.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fgl-5.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl
hs-libraries:         HSfgl-5.8.2.0-Eb6xdEigYbA8WAuh82pZJA
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html:         /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
